@@ -1,5 +1,4 @@
-__author__ = 'CTK'
-
+from __future__ import print_function
 from mbuild.coordinate_transform import equivalence_transform
 from mbuild.compound import Compound
 
@@ -8,8 +7,7 @@ from silane import Silane
 
 
 class AlkylSilane(Compound):
-    """
-    """
+    """A silane functionalized alkane chain with one Port. """
     def __init__(self, chain_length):
         """
         """
@@ -28,23 +26,12 @@ if __name__ == "__main__":
     alkyl_silane = AlkylSilane(100)
     alkyl_silane = alkyl_silane.to_trajectory()
 
-    import cProfile, pstats, StringIO
-    pr = cProfile.Profile()
-    pr.enable()
-
     alkyl_silane.top.find_forcefield_terms()
 
-    pr.disable()
-    s = StringIO.StringIO()
-    sortby = 'cumulative'
-    ps = pstats.Stats(pr, stream=s).sort_stats(sortby)
-    ps.print_stats()
-    print s.getvalue()
-
-    print alkyl_silane.n_atoms
-    print alkyl_silane.top.n_ff_bonds
-    print alkyl_silane.top.n_ff_angles
-    print alkyl_silane.top.n_ff_dihedrals
+    print(alkyl_silane.n_atoms)
+    print(alkyl_silane.top.n_ff_bonds)
+    print(alkyl_silane.top.n_ff_angles)
+    print(alkyl_silane.top.n_ff_dihedrals)
 
     #from mbuild.plot import Plot
     #Plot(alkyl_silane, bonds=True, verbose=False).show()
