@@ -12,21 +12,21 @@ from silane import Silane
 class Brush(Compound):
     """ """
     def __init__(self, chain_length=4, alpha=pi/4):
-        Compound.__init__(self)
+        super(Brush, self).__init__(self)
 
         # Add parts
         self.add(Silane(), 'silane')
         self.add(Initiator(), 'initiator')
         self.add(Polymer(MpcMonomer(alpha=alpha), n=chain_length,
-                         port_labels=("top_port", "bottom_port")), 'pmpc')
+                         port_labels=('up', 'down')), 'pmpc')
         self.add(Methyl(), 'methyl')
 
-        equivalence_transform(self.initiator, self.initiator.bottom_port, self.silane.top_port)
-        equivalence_transform(self.pmpc, self.pmpc.bottom_port, self.initiator.top_port)
-        equivalence_transform(self.methyl, self.methyl.down, self.pmpc.top_port)
+        equivalence_transform(self.initiator, self.initiator.down, self.silane.up)
+        equivalence_transform(self.pmpc, self.pmpc.down, self.initiator.up)
+        equivalence_transform(self.methyl, self.methyl.down, self.pmpc.up)
 
-        # make self.port point to silane.bottom_port
-        self.add(self.silane.bottom_port, label="port", containment=False)
+        # Make self.port point to silane.bottom_port
+        self.add(self.silane.down, label="port", containment=False)
 
 if __name__ == "__main__":
     m = Brush(chain_length=20, alpha=pi/4)
