@@ -1,16 +1,17 @@
 import random
 from copy import deepcopy
 
-import numpy as np
+from numpy import pi
 
 from mbuild.examples.tnp.tnp import Tnp
 from mbuild.compound import Compound
-from mbuild.coordinate_transform import translate, rotate_around_x, rotate_around_y, rotate_around_z
+from mbuild.coordinate_transform import translate, rotate_around_x,\
+    rotate_around_y, rotate_around_z
 from mbuild.tools.mask import grid_mask_3d
 
-__author__ = 'sallai'
 
 class TnpBox(Compound):
+    """Several tethered nanoparticles randomly dispersed in a Box. """
     def __init__(self):
         super(TnpBox, self).__init__(self)
 
@@ -23,9 +24,9 @@ class TnpBox(Compound):
 
         for pos in mask:
             tnp = deepcopy(tnp_proto)
-            rotate_around_x(tnp, rnd.uniform(0, 2*np.pi))
-            rotate_around_y(tnp, rnd.uniform(0, 2*np.pi))
-            rotate_around_z(tnp, rnd.uniform(0, 2*np.pi))
+            rotate_around_x(tnp, rnd.uniform(0, 2 * pi))
+            rotate_around_y(tnp, rnd.uniform(0, 2 * pi))
+            rotate_around_z(tnp, rnd.uniform(0, 2 * pi))
             translate(tnp, pos)
             self.add(tnp)
 
